@@ -6,7 +6,13 @@
 #include "pdl.h"      /* Data structure declarations */
 #include "pdlcore.h"  /* Core declarations */
 
-/* Free the data if possible; used by mmapper */
+/*
+ * DJB July 10 2006
+ * moved from pdlhash.c into Core.xs since it only seems to
+ * be used there (and is not defined in any .h file so
+ * should not be used by code outside Core/)
+ *
+ * Free the data if possible; used by mmapper
 void pdl_freedata (pdl *a) {
 	if(a->datasv) {
 		SvREFCNT_dec(a->datasv);
@@ -16,6 +22,7 @@ void pdl_freedata (pdl *a) {
 		die("Trying to free data of untouchable (mmapped?) pdl");
 	}
 }
+*/
 
 /*  Utility to change the size of the data compt of a pdl */
 
@@ -23,8 +30,8 @@ void pdl_grow (pdl* a, int newsize) {
 
    SV* foo;
    HV* hash;
-   int nbytes;
-   int ncurr;
+   STRLEN nbytes;
+   STRLEN ncurr;
    STRLEN len;
 
    if(a->state & PDL_DONTTOUCHDATA) {
@@ -36,7 +43,7 @@ void pdl_grow (pdl* a, int newsize) {
 
    foo = a->datasv;
 
-   nbytes = newsize * pdl_howbig(a->datatype);
+   nbytes = ((STRLEN) newsize) * pdl_howbig(a->datatype);
    ncurr  = SvCUR( foo );
    if (ncurr == nbytes)
       return;    /* Nothing to be done */
@@ -69,7 +76,7 @@ void pdl_unpackarray ( HV* hash, char *key, int *dims, int ndims ) {
    int i;
 
    array = newAV();
-   hv_store(hash, key, strlen(key), newRV( (SV*) array), 0 );
+   (void)hv_store(hash, key, strlen(key), newRV( (SV*) array), 0 );
 
    if (ndims==0 )
       return;
