@@ -87,7 +87,7 @@ $PDL::IO::Pic::debug = $PDL::IO::Pic::debug || 0;
 
 sub init_converter_table {
   # default flag to be used with any converter unless overridden with FLAGS
-  $Dflags = '-quiet';
+  $Dflags = '';
   %converter = ();
 
   # Pbmplus systems have cjpeg/djpeg; netpbm systems have pnmtojpeg and
@@ -565,22 +565,27 @@ use PDL::IO::Pic;
 sub rim {
   my(@args) = @_;
 
-  if(@args == 2) {
-    my($dest) = $args[0];
-    if($dest->dim(0) == 3) {
-      $args[0] = $dest->reorder(1,2,0);
-    }
-    return rpic(@args);
+  my $out;
+
+  ## Handle dest-PDL-first case
+  if(@args >= 2 and (UNIVERSAL::isa($args[0],'PDL'))) {
+      my $dest = shift @args;
+      my $rpa = PDL->null;
+      $out = rpic(@args);
+
+      if($out->ndims == 3 && $out->dim(0) == 3 &&
+	 !( defined($out->gethdr) && $out->gethdr->{SIMPLE} )
+	  ) {
+	  $out =  $out->reorder(1,2,0);
+      }
+      
+      $dest .= $out;
+      return $out;
   }
 
-  my $out = rpic(@args);
+  # Handle no-first-PDL case
+  $out = rpic(@args);
 
-  #
-  # Check for RGB and reorder dims if necessary.  The SIMPLE test is to check
-  # if the image has a FITS header.
-  #
-  # (What a kludge -- but rpic is historical and has to be kept at this point)
-  #
   if($out->ndims == 3 && $out->dim(0) == 3 &&
      !( defined($out->gethdr) && $out->gethdr->{SIMPLE} )
      ) {
@@ -876,6 +881,7 @@ sub chkform {
     my ($format, $magic, $len, $ext) = ("","",0,"");
 
     open(IMG, $file) or barf "Can't open image file";
+    binmode IMG;
     # should first check if file is long enough
     $len = read(IMG, $magic,12);
     if (!defined($len) ||$len != 12) {
